﻿using Microsoft.EntityFrameworkCore;

namespace ELTE.TodoList.Web.Models
{
    public class TodoListDbContext : DbContext
    {
        public DbSet<List> Lists { get; set; } = null!;
        public DbSet<Item> Items { get; set; } = null!;

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            IConfigurationBuilder configBuilder = new ConfigurationBuilder()
                .SetBasePath(Directory.GetCurrentDirectory())
                .AddJsonFile("appsettings.json", optional: true, reloadOnChange: true);
            IConfigurationRoot configuration = configBuilder.Build();

            DbType dbType = configuration.GetValue<DbType>("DbType");

            switch (dbType)
            {
                case DbType.SqlServer:
                    // Need Microsoft.EntityFrameworkCore.SqlServer package for this
                    optionsBuilder.UseSqlServer(configuration.GetConnectionString("SqlServerConnection"));
                    break;

                case DbType.Sqlite:
                    // Need Microsoft.EntityFrameworkCore.Sqlite package for this
                    optionsBuilder.UseSqlite(configuration.GetConnectionString("SqliteConnection"));
                    break;
            }

            // Use lazy loading (don't forget the virtual keyword on the navigational properties also)
            optionsBuilder.UseLazyLoadingProxies();
        }
    }
}
